@@ -160,6 +160,9 @@ class ContentExporter(UniqueObject, SimpleItem):
             output = doc[0].toprettyxml(indent="  ")
             if headfoot and headfoot != 'DEFAULT':
                 # Add html at end of xml
+                # Close and reopen any existing CDATA
+                headfoot = headfoot.replace(']]>',']]]]><![CDATA[>')
+                # Wrap in CDATA to prevent tags breaking xml validation
                 return output.replace('</properties>',
                                       '''<html><![CDATA[\n%s]]></html>
                                          \n</properties>''' % headfoot)
