@@ -244,8 +244,8 @@ class SFWA(StructureFolderWalkingAdapter):
                     if len(parts) > 1:
                         meta = parts[0]
                         meta = "[DEFAULT]\n%s" % parts[0]
-                        if hasattr(obj,'setText'):
-                            obj.setText(parts[1])
+                        if hasattr(obj, 'setText'):
+                            obj.setText(parts[1], mimetype='text/html')
                         else:
                             try:
                                 obj['text'] = parts[1]
@@ -255,7 +255,7 @@ class SFWA(StructureFolderWalkingAdapter):
                         self.out.append('Found no metadata for obj %s' % obj.getId())
                     self.put_props(obj, meta, import_context, subdir)
 
-        if getattr(self,'reindex','item') == 'item':
+        if getattr(self, 'reindex', 'item') == 'item':
             obj.indexObject()
 
         return obj
@@ -356,12 +356,15 @@ class SFWA(StructureFolderWalkingAdapter):
             fields.remove(pname)
         for f in fields:
             name = f.getName()
-            value = metadata.get(name,metadata.get(name.lower(), None))
+            # Stop setting text without html mimetype
+            if name == 'text':
+                continue
+            value = metadata.get(name, metadata.get(name.lower(), None))
             #debug self.out.append('add %s - %s = %s' % (typename, name, value))
             if value:
                 typename = f.type 
                 written = False
-                if typename in ('file','image'):
+                if typename in ('file', 'image'):
                     if value == 'EXTRAFILE':
                         filename = '%s.%s' % (obj.getId(), name)
                         data = import_context.readDataFile(filename, subdir)
@@ -376,8 +379,11 @@ class SFWA(StructureFolderWalkingAdapter):
                         value = atconvert[typename](value)
                     mutator = f.getMutator(obj)
                     if mutator:
-                        mutator(value)
-                        written = True
+                        try:
+                            mutator(value)
+                            written = True
+                        except:
+                            written = False
                         #debug self.out.append(
                         #   'convert %s to %s and add with %s' % (invalue, value, mutator))
                 if not written:
@@ -388,6 +394,8 @@ class SFWA(StructureFolderWalkingAdapter):
         """ Pull out dublin core properties
         """
         for key, value in metadata.items():
+            if key == 'text':
+                continue
             if value:
                 if type(value)!=StringType and type(value) in [ListType, TupleType]:
                     value = value.split(SEPARATOR)
